@@ -77,6 +77,9 @@ FAILEDOPERATION_SDKNOPACKAGE = 'FailedOperation.SdkNoPackage'
 # The stream does not exist.
 FAILEDOPERATION_STREAMNOTEXIST = 'FailedOperation.StreamNotExist'
 
+# Failed to unbind the tag. Try unbinding it manually.
+FAILEDOPERATION_TAGUNBINDERROR = 'FailedOperation.TagUnbindError'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
@@ -95,7 +98,7 @@ INTERNALERROR_CONFINUSED = 'InternalError.ConfInUsed'
 # The template does not exist.
 INTERNALERROR_CONFNOTFOUND = 'InternalError.ConfNotFound'
 
-# The number of templates exceeds the limit.
+# The number of templates exceeded the limit.
 INTERNALERROR_CONFOUTLIMIT = 'InternalError.ConfOutLimit'
 
 # The configuration does not exist.
